import { defineNuxtModule, createResolver, addPlugin, addImports } from '@nuxt/kit';

function _defu(baseObject, defaults, namespace = ".", merger) {
  if (!_isPlainObject(defaults)) {
    return _defu(baseObject, {}, namespace, merger);
  }
  const object = Object.assign({}, defaults);
  for (const key in baseObject) {
    if (key === "__proto__" || key === "constructor") {
      continue;
    }
    const value = baseObject[key];
    if (value === null || value === void 0) {
      continue;
    }
    if (merger && merger(object, key, value, namespace)) {
      continue;
    }
    if (Array.isArray(value) && Array.isArray(object[key])) {
      object[key] = [...value, ...object[key]];
    } else if (_isPlainObject(value) && _isPlainObject(object[key])) {
      object[key] = _defu(
        value,
        object[key],
        (namespace ? `${namespace}.` : "") + key.toString(),
        merger
      );
    } else {
      object[key] = value;
    }
  }
  return object;
}
function _isPlainObject(value) {
  if (value === null || typeof value !== "object") {
    return false;
  }
  const prototype = Object.getPrototypeOf(value);
  return (prototype === null || prototype === Object.prototype || Object.getPrototypeOf(prototype) === null) && !(Symbol.toStringTag in value) && !(Symbol.iterator in value);
}
function createDefu(merger) {
  return (...arguments_) => (
    // eslint-disable-next-line unicorn/no-array-reduce
    arguments_.reduce((p, c) => _defu(p, c, "", merger), {})
  );
}
const defu = createDefu();

const module = defineNuxtModule({
  meta: {
    name: "bageldb",
    configKey: "BagelDB",
    compatibility: {
      bridge: true
    }
  },
  // Default configuration options of the Nuxt module
  defaults: {
    alias: "db"
  },
  setup(options, nuxt) {
    const resolver = createResolver(import.meta.url);
    nuxt.options.runtimeConfig.bageldb = defu(nuxt.options.runtimeConfig.bageldb, {
      ...options
    });
    if (options.exposePublicClient) {
      nuxt.options.runtimeConfig.public.bageldb = defu(nuxt.options.runtimeConfig.bageldb, {
        ...options
      });
    }
    addPlugin({
      src: resolver.resolve("./runtime/plugin"),
      mode: "server"
    });
    addPlugin({
      src: resolver.resolve("./runtime/plugin"),
      mode: "client"
    });
    const composables = resolver.resolve("./runtime/composables");
    addImports([{ from: composables, name: "useBagelDB" }]);
  }
});

export { module as default };
